/*
 * htmlTbl
 *
 * output an HTML-formatted table from database inputs
 *
 * Copyright    (c)    1997    Microsoft Corporation
 */

import com.ms.com.Variant;
import java.io.*;
import msado10.*;   // Microsoft OLE DB ActiveX Data Objects 1.0 Library
import asp.*;		// Microsoft Active Server Pages 1.0 Object Library

/*
 * htmlTbl is a simple java class for outputting HTML tables
 */

class htmlTbl 
{
    boolean Borders = true;
    boolean HeadingRow = true;
    String Caption = "";
    String CaptionStyle = "";

    IScriptingContext isc = null;

    // This optional method is called by ASP whenever a page containing a
    // htmlTbl object is loaded by the user's browser.  Note that
    // OnStartPage is not called for application-level objects.  If the
    // object is created by a method other than a call to
    // Server.CreateObject or <OBJECT RUNAT=SERVER ...>, then OnStartPage
    // might not be called.  If you rely on interfaces obtained through
    // IScriptingContext in OnStartPage, you should always check that those
    // interfaces are correctly initialized in the routines that use them.
    public void OnStartPage(IScriptingContext objContext)
    {
        isc = objContext;
    }

    // This optional method is called by ASP whenever a page containing a
    // JavaPwr object is unloaded by the user's browser.  You should
    // release any interfaces obtained in OnStartPage here, as they will
    // not be valid outside the scope of OnStartPage/OnEndPage.
    public void OnEndPage()
    {
        isc = null;
    }

    public void AutoFormat(_Recordset r)
    {
        try
        {
            Variant idx = new Variant();
            IResponse rsp = isc.getResponse();
            
            // if empty result set, return a useful message
            if (r.getEOF())
            {
                Variant x = new Variant();
                x.putString("<h2>?EOF on result set</h2>");
                rsp.Write(x);
                return;
            }
            
            String obuf = "<table";

            if (Borders)
                obuf += " border=1";
            obuf += ">\n";

            // <caption> is an Internet Explorer-specific extension to
            // HTML tables
            if (Caption != "")
            {
                obuf += "<caption";
                if (CaptionStyle != "")
                    obuf += " " + CaptionStyle;
                obuf += ">" + Caption + "</caption>\n";
            }
            
            // Conditionally put out headers
            if (HeadingRow)
            {
                Fields f = r.getFields();
                int end = f.getCount();
                obuf += "\n<tr>\n";

                for (int i = 0; i < end; i++)
                {
                    idx.putInt(i);
                    String fname = f.getItem(idx).getName();

                    obuf += "\t<th>";
                    if (fname == "")
                        obuf += "&nbsp;";
                    else
                        obuf += fname;
                    obuf += "</th>\n";
                }
                obuf += "</tr>\n";
            }
            
            // Put out each row of the table
            while (!r.getEOF())
            {
                Fields f = r.getFields();
                int end = f.getCount();
                obuf += "\n<tr>\n";

                for (int i = 0; i < end; i++)
                {
                    idx.putInt(i);
                    Variant fv = f.getItem(idx).getValue();

                    obuf += "\t<td>";
                    String tmp = fv.toString();
                    if (tmp == "")
                        obuf += "&nbsp;";
                    else
                        obuf += tmp;
                    obuf += "</td>\n";
                }
                obuf += "</tr>\n";
                r.MoveNext();
            }

            obuf += "\n</table>\n\n";
            
            Variant x = new Variant();
            x.putString(obuf);
            rsp.Write(x);
        }
        catch (Throwable t)
        {
            IResponse rsp = isc.getResponse();
            Variant x = new Variant();
            x.putString("<h2>Error: " + t.toString() + "</h2>");
            rsp.Write(x);
        }
    }
}
